@@ -25,11 +25,18 @@
 #include <KConfigGroup>
 
 #include <QMimeData>
+#include <QStandardPaths>
 
 using namespace KIdentityManagement;
 
 QTEST_GUILESS_MAIN(IdentityTester)
 
+void IdentityTester::initTestCase()
+{
+    QStandardPaths::setTestModeEnabled(true);
+}
+
+
 void IdentityTester::test_NullIdentity()
 {
     IdentityManager manager;
@@ -78,7 +85,7 @@ void IdentityTester::test_toMimeData()
 {
     IdentityManager manager;
     Identity &identity = manager.newFromScratch(QStringLiteral("Test1"));
-    identity.setFullName(QLatin1String("name"));
+    identity.setFullName(QStringLiteral("name"));
     QMimeData mimeData;
     identity.populateMimeData(&mimeData);
 
