@@ -51,9 +51,6 @@ Identity::Identity(const QString &id, const QString &fullName,
     setProperty(QLatin1String(s_defaultDomainName), QHostInfo::localHostName());
 }
 
-Identity::~Identity()
-{}
-
 const Identity &Identity::null()
 {
     if (!identityNull) {
@@ -131,7 +128,7 @@ bool Identity::mailingAllowed() const
 
 QString Identity::mimeDataType()
 {
-    return QLatin1String("application/x-kmail-identity-drag");
+    return QStringLiteral("application/x-kmail-identity-drag");
 }
 
 bool Identity::canDecode(const QMimeData *md)
@@ -290,7 +287,7 @@ QString Identity::fullEmailAddr(void) const
         return mail;
     }
 
-    const QString specials(QLatin1String("()<>@,.;:[]"));
+    const QString specials(QStringLiteral("()<>@,.;:[]"));
 
     QString result;
 
