@@ -34,10 +34,10 @@ static const char configKeyDefaultIdentity[] = "Default Identity";
 #include <kdelibs4configmigrator.h>
 
 #include <QList>
-#include <QRegExp>
 #include <QtDBus/QtDBus>
 #include <QHostInfo>
 
+#include <QRegularExpression>
 #include <assert.h>
 #include <krandom.h>
 
@@ -62,7 +62,7 @@ static QString newDBusObjectName()
  *   @internal
  */
 //@cond PRIVATE
-class KIdentityManagement::IdentityManager::Private
+class Q_DECL_HIDDEN KIdentityManagement::IdentityManager::Private
 {
 public:
     Private(KIdentityManagement::IdentityManager *);
@@ -100,7 +100,7 @@ void IdentityManager::Private::writeConfig() const
     ConstIterator end = mIdentities.constEnd();
     for (ConstIterator it = mIdentities.constBegin();
             it != end; ++it, ++i) {
-        KConfigGroup cg(mConfig, QString::fromLatin1("Identity #%1").arg(i));
+        KConfigGroup cg(mConfig, QStringLiteral("Identity #%1").arg(i));
         (*it).writeConfig(cg);
         if ((*it).isDefault()) {
             // remember which one is default:
@@ -234,7 +234,7 @@ void IdentityManager::Private::createDefaultIdentity()
 
 QStringList IdentityManager::Private::groupList(KConfig *config) const
 {
-    return config->groupList().filter(QRegExp(QStringLiteral("^Identity #\\d+$")));
+    return config->groupList().filter(QRegularExpression(QStringLiteral("^Identity #\\d+$")));
 }
 
 int IdentityManager::Private::newUoid()
@@ -273,9 +273,8 @@ int IdentityManager::Private::newUoid()
 void IdentityManager::Private::slotIdentitiesChanged(const QString &id)
 {
     qCDebug(KIDENTITYMANAGEMENT_LOG) << " KIdentityManagement::IdentityManager::slotIdentitiesChanged :" << id;
-    const QString ourIdentifier = QString::fromLatin1("%1/%2").
-                                  arg(QDBusConnection::sessionBus().baseService()).
-                                  arg(q->property("uniqueDBusPath").toString());
+    const QString ourIdentifier = QStringLiteral("%1/%2").
+                                  arg(QDBusConnection::sessionBus().baseService(), q->property("uniqueDBusPath").toString());
     if (id != ourIdentifier) {
         mConfig->reparseConfiguration();
         Q_ASSERT(!q->hasPendingChanges());
@@ -441,9 +440,8 @@ void IdentityManager::commit()
     emit changed(); // normal signal
 
     // DBus signal for other IdentityManager instances
-    const QString ourIdentifier = QString::fromLatin1("%1/%2").
-                                  arg(QDBusConnection::sessionBus().baseService()).
-                                  arg(property("uniqueDBusPath").toString());
+    const QString ourIdentifier = QStringLiteral("%1/%2").
+                                  arg(QDBusConnection::sessionBus().baseService(), property("uniqueDBusPath").toString());
     emit identitiesChanged(ourIdentifier);
 }
 
