@@ -35,14 +35,16 @@
 
 #include <assert.h>
 #include <QtCore/QDir>
-#include <kpimtextedit/textedit.h>
+#include <kpimtextedit/richtextcomposer.h>
+#include <kpimtextedit/richtextcomposercontroler.h>
+#include <kpimtextedit/richtextcomposerimages.h>
 
 using namespace KIdentityManagement;
 
-class KIdentityManagement::Signature::Private
+class Q_DECL_HIDDEN KIdentityManagement::SignaturePrivate
 {
 public:
-    Private(Signature *qq)
+    SignaturePrivate(Signature *qq)
         : enabled(false),
           q(qq)
     {
@@ -53,7 +55,7 @@ public:
     void saveImages() const;
     QString textFromFile(bool *ok) const;
     QString textFromCommand(bool *ok) const;
-    void insertSignatureText(Signature::Placement placement, Signature::AddedText addedText, KPIMTextEdit::TextEdit *textEdit, bool forceDisplay) const;
+    void insertSignatureText(Signature::Placement placement, Signature::AddedText addedText, KPIMTextEdit::RichTextComposer *textEdit, bool forceDisplay) const;
 
     /// List of images that belong to this signature. Either added by addImage() or
     /// by readConfig().
@@ -77,7 +79,7 @@ static bool isCursorAtEndOfLine(const QTextCursor &cursor)
 }
 
 static void insertSignatureHelper(const QString &signature,
-                                  KRichTextEdit *textEdit,
+                                  KPIMTextEdit::RichTextComposer *textEdit,
                                   Signature::Placement placement,
                                   bool isHtml,
                                   bool addNewlines)
@@ -105,7 +107,7 @@ static void insertSignatureHelper(const QString &signature,
         QString lineSep;
         if (addNewlines) {
             if (isHtml) {
-                lineSep = QLatin1String("<br>");
+                lineSep = QStringLiteral("<br>");
             } else {
                 lineSep = QLatin1Char('\n');
             }
@@ -159,7 +161,7 @@ static void insertSignatureHelper(const QString &signature,
         textEdit->document()->setModified(isModified);
 
         if (isHtml) {
-            textEdit->enableRichTextMode();
+            textEdit->activateRichText();
         }
     }
 }
@@ -170,9 +172,9 @@ static QStringList findImageNames(const QString &htmlCode)
     QStringList ret;
 
     // To complicated for us, so cheat and let a text edit do the hard work
-    KPIMTextEdit::TextEdit edit;
+    KPIMTextEdit::RichTextComposer edit;
     edit.setHtml(htmlCode);
-    QList<KPIMTextEdit::ImageWithNamePtr> images = edit.imagesWithName();
+    QList<KPIMTextEdit::ImageWithNamePtr> images = edit.composerControler()->composerImages()->imagesWithName();
     ret.reserve(images.count());
     foreach (const KPIMTextEdit::ImageWithNamePtr &image, images) {
         ret << image->name;
@@ -180,7 +182,7 @@ static QStringList findImageNames(const QString &htmlCode)
     return ret;
 }
 
-void Signature::Private::assignFrom(const KIdentityManagement::Signature &that)
+void SignaturePrivate::assignFrom(const KIdentityManagement::Signature &that)
 {
     url = that.url();
     inlinedHtml = that.isInlinedHtml();
@@ -191,7 +193,7 @@ void Signature::Private::assignFrom(const KIdentityManagement::Signature &that)
     embeddedImages = that.embeddedImages();
 }
 
-void Signature::Private::cleanupImages()
+void SignaturePrivate::cleanupImages()
 {
     // Remove any images from the internal structure that are no longer there
     if (inlinedHtml) {
@@ -221,7 +223,7 @@ void Signature::Private::cleanupImages()
     }
 }
 
-void Signature::Private::saveImages() const
+void SignaturePrivate::saveImages() const
 {
     if (inlinedHtml && !saveLocation.isEmpty()) {
         foreach (const Signature::EmbeddedImagePtr &image, embeddedImages) {
@@ -233,9 +235,9 @@ void Signature::Private::saveImages() const
     }
 }
 
-QString Signature::Private::textFromFile(bool *ok) const
+QString SignaturePrivate::textFromFile(bool *ok) const
 {
-    assert(type == FromFile);
+    assert(type == Signature::FromFile);
 
     // TODO: Use KIO::NetAccess to download non-local files!
     const QUrl u(url);
@@ -264,9 +266,9 @@ QString Signature::Private::textFromFile(bool *ok) const
     return QString::fromLocal8Bit(ba.data(), ba.size());
 }
 
-QString Signature::Private::textFromCommand(bool *ok) const
+QString SignaturePrivate::textFromCommand(bool *ok) const
 {
-    assert(type == FromCommand);
+    assert(type == Signature::FromCommand);
 
     // handle pathological cases:
     if (url.isEmpty()) {
@@ -305,7 +307,7 @@ QString Signature::Private::textFromCommand(bool *ok) const
     return QString::fromLocal8Bit(output.data(), output.size());
 }
 
-void Signature::Private::insertSignatureText(Placement placement, AddedText addedText, KPIMTextEdit::TextEdit *textEdit, bool forceDisplay) const
+void SignaturePrivate::insertSignatureText(Signature::Placement placement, Signature::AddedText addedText, KPIMTextEdit::RichTextComposer *textEdit, bool forceDisplay) const
 {
     if (!forceDisplay) {
         if (!enabled) {
@@ -313,7 +315,7 @@ void Signature::Private::insertSignatureText(Placement placement, AddedText adde
         }
     }
     QString signature;
-    if (addedText & AddSeparator) {
+    if (addedText & Signature::AddSeparator) {
         signature = q->withSeparator();
     } else {
         signature = q->rawText();
@@ -321,12 +323,12 @@ void Signature::Private::insertSignatureText(Placement placement, AddedText adde
     insertSignatureHelper(signature, textEdit, placement,
                           (inlinedHtml &&
                            type == KIdentityManagement::Signature::Inlined),
-                          (addedText & AddNewLines));
+                          (addedText & Signature::AddNewLines));
 
     // We added the text of the signature above, now it is time to add the images as well.
     if (inlinedHtml) {
         foreach (const Signature::EmbeddedImagePtr &image, embeddedImages) {
-            textEdit->loadImage(image->image, image->name, image->name);
+            textEdit->composerControler()->composerImages()->loadImage(image->image, image->name, image->name);
         }
     }
 }
@@ -342,14 +344,14 @@ QDataStream &operator>> (QDataStream &stream, KIdentityManagement::Signature::Em
 }
 
 Signature::Signature()
-    : d(new Private(this))
+    : d(new SignaturePrivate(this))
 {
     d->type = Disabled;
     d->inlinedHtml = false;
 }
 
 Signature::Signature(const QString &text)
-    : d(new Private(this))
+    : d(new SignaturePrivate(this))
 {
     d->type = Inlined;
     d->inlinedHtml = false;
@@ -357,14 +359,14 @@ Signature::Signature(const QString &text)
 }
 
 Signature::Signature(const QString &url, bool isExecutable)
-    : d(new Private(this))
+    : d(new SignaturePrivate(this))
 {
     d->type = isExecutable ? FromCommand : FromFile;
     d->url = url;
 }
 
 Signature::Signature(const Signature &that)
-    : d(new Private(this))
+    : d(new SignaturePrivate(this))
 {
     d->assignFrom(that);
 }
@@ -418,18 +420,18 @@ QString Signature::withSeparator(bool *ok) const
     }
 
     const bool htmlSig = (isInlinedHtml() && d->type == Inlined);
-    QString newline = htmlSig ? QLatin1String("<br>") : QLatin1String("\n");
-    if (htmlSig && signature.startsWith(QLatin1String("<p"))) {
+    QString newline = htmlSig ? QStringLiteral("<br>") : QStringLiteral("\n");
+    if (htmlSig && signature.startsWith(QStringLiteral("<p"))) {
         newline.clear();
     }
 
-    if (signature.startsWith(QString::fromLatin1("-- ") + newline) ||
-            (signature.indexOf(newline + QString::fromLatin1("-- ") + newline) != -1)) {
+    if (signature.startsWith(QLatin1String("-- ") + newline) ||
+            (signature.indexOf(newline + QLatin1String("-- ") + newline) != -1)) {
         // already have signature separator at start of sig or inside sig:
         return signature;
     } else {
         // need to prepend one:
-        return QString::fromLatin1("-- ") + newline + signature;
+        return QLatin1String("-- ") + newline + signature;
     }
 }
 
@@ -526,7 +528,7 @@ void Signature::writeConfig(KConfigGroup &config) const
 }
 
 void Signature::insertIntoTextEdit(Placement placement, AddedText addedText,
-                                   KPIMTextEdit::TextEdit *textEdit, bool forceDisplay) const
+                                   KPIMTextEdit::RichTextComposer *textEdit, bool forceDisplay) const
 {
     d->insertSignatureText(placement, addedText, textEdit, forceDisplay);
 }
