@@ -42,12 +42,12 @@ class KRichTextEdit;
 
 namespace KPIMTextEdit
 {
-class TextEdit;
+class RichTextComposer;
 }
 
 namespace KIdentityManagement
 {
-
+class SignaturePrivate;
 KIDENTITYMANAGEMENT_EXPORT QDataStream &operator<<
 (QDataStream &stream, const KIdentityManagement::Signature &sig);
 KIDENTITYMANAGEMENT_EXPORT QDataStream &operator>>
@@ -249,7 +249,7 @@ public:
     // TODO: KDE5: BIC: Reorder parameters, the order here is a workaround for ambiguous parameters
     //                  with the deprecated method
     void insertIntoTextEdit(Placement placement, AddedText addedText,
-                            KPIMTextEdit::TextEdit *textEdit, bool forceDisplay = false) const;
+                            KPIMTextEdit::RichTextComposer *textEdit, bool forceDisplay = false) const;
 
     QList<Signature::EmbeddedImagePtr> embeddedImages() const;
     void setEmbeddedImages(const QList<Signature::EmbeddedImagePtr> &embedded);
@@ -262,8 +262,7 @@ protected:
 
 private:
     //@cond PRIVATE
-    class Private;
-    Private *const d;
+    SignaturePrivate *const d;
     //@endcond
 };
 
