@@ -31,7 +31,9 @@
 #include <QUrl>
 #include <KComboBox>
 
-#include <kpimtextedit/textedit.h>
+#include <KPIMTextEdit/RichTextComposer>
+#include <KPIMTextEdit/RichTextComposerImages>
+#include <KPIMTextEdit/RichTextComposerControler>
 
 #include <QCheckBox>
 #include <QDir>
@@ -46,6 +48,8 @@
 #include <assert.h>
 #include <QStandardPaths>
 
+#include <kpimtextedit/richtexteditorwidget.h>
+
 using namespace KIdentityManagement;
 
 namespace KIdentityManagement
@@ -56,7 +60,7 @@ namespace KIdentityManagement
    @internal
   */
 //@cond PRIVATE
-class SignatureConfigurator::Private
+class Q_DECL_HIDDEN SignatureConfigurator::Private
 {
 public:
     Private(SignatureConfigurator *parent);
@@ -76,8 +80,7 @@ public:
     KLineEdit        *mCommandEdit;
     KToolBar         *mEditToolBar;
     KToolBar         *mFormatToolBar;
-    KRichTextWidget *mTextEdit;
-    // This is a KPIMTextEdit::TextEdit, really.
+    KPIMTextEdit::RichTextComposer *mTextEdit;
 
 };
 //@endcond
@@ -174,23 +177,15 @@ void SignatureConfigurator::Private::init()
     page_vlay->addWidget(mFormatToolBar, 1);
 #endif
 
-    mTextEdit = new KPIMTextEdit::TextEdit(q);
-    static_cast<KPIMTextEdit::TextEdit *>(mTextEdit)->enableImageActions();
-    static_cast<KPIMTextEdit::TextEdit *>(mTextEdit)->enableInsertHtmlActions();
-    static_cast<KPIMTextEdit::TextEdit *>(mTextEdit)->enableInsertTableActions();
-    page_vlay->addWidget(mTextEdit, 2);
+    mTextEdit = new KPIMTextEdit::RichTextComposer(q);
+
+    KPIMTextEdit::RichTextEditorWidget *richTextEditorwidget = new KPIMTextEdit::RichTextEditorWidget(mTextEdit, q);
+    page_vlay->addWidget(richTextEditorwidget, 2);
     mTextEdit->setWhatsThis(i18n("Use this field to enter an arbitrary static signature."));
-    // exclude SupportToPlainText.
-    mTextEdit->setRichTextSupport(KRichTextWidget::FullTextFormattingSupport |
-                                  KRichTextWidget::FullListSupport |
-                                  KRichTextWidget::SupportAlignment |
-                                  KRichTextWidget::SupportRuleLine |
-                                  KRichTextWidget::SupportHyperlinks |
-                                  KRichTextWidget::SupportFormatPainting);
 
     // Fill the toolbars.
     KActionCollection *actionCollection = new KActionCollection(q);
-    actionCollection->addActions(mTextEdit->createActions());
+    mTextEdit->createActions(actionCollection);
 #ifndef QT_NO_TOOLBAR
     mEditToolBar->addAction(actionCollection->action(QStringLiteral("format_text_bold")));
     mEditToolBar->addAction(actionCollection->action(QStringLiteral("format_text_italic")));
@@ -374,7 +369,7 @@ Signature SignatureConfigurator::signature() const
             if (!d->imageLocation.isEmpty()) {
                 sig.setImageLocation(d->imageLocation);
             }
-            KPIMTextEdit::ImageWithNameList images = static_cast< KPIMTextEdit::TextEdit *>(d->mTextEdit)->imagesWithName();
+            KPIMTextEdit::ImageWithNameList images = d->mTextEdit->composerControler()->composerImages()->imagesWithName();
             foreach (const KPIMTextEdit::ImageWithNamePtr &image, images) {
                 sig.addImage(image->image, image->name);
             }
@@ -409,9 +404,8 @@ void SignatureConfigurator::setSignature(const Signature &sig)
 
     // Let insertIntoTextEdit() handle setting the text, as that function also adds the images.
     d->mTextEdit->clear();
-    KPIMTextEdit::TextEdit *const pimEdit = static_cast<KPIMTextEdit::TextEdit *>(d->mTextEdit);
     sig.insertIntoTextEdit(KIdentityManagement::Signature::Start, KIdentityManagement::Signature::AddNothing,
-                           pimEdit, true);
+                           d->mTextEdit, true);
     if (sig.type() == Signature::FromFile) {
         setFileURL(sig.url());
     } else {
@@ -461,7 +455,7 @@ void SignatureConfigurator::slotSetHtml()
         d->mFormatToolBar->setVisible(true);
         d->mFormatToolBar->setEnabled(true);
 #endif
-        d->mTextEdit->enableRichTextMode();
+        d->mTextEdit->activateRichText();
     }
 }
 
@@ -472,7 +466,7 @@ void SignatureConfigurator::setImageLocation(const QString &path)
 
 void SignatureConfigurator::setImageLocation(const Identity &identity)
 {
-    const QString dir = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('/') + QString::fromLatin1("emailidentities/%1/").arg(
+    const QString dir = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('/') + QStringLiteral("emailidentities/%1/").arg(
                             QString::number(identity.uoid()));
     QFileInfo fileInfo(dir);
     QDir().mkpath(fileInfo.absolutePath());
